"""
Python module generated from Java source file org.bukkit.event.entity.EntityPortalEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import Entity
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityPortalEvent(EntityTeleportEvent):
    """
    Called when a non-player entity is about to teleport because it is in
    contact with a portal.
    
    For players see org.bukkit.event.player.PlayerPortalEvent
    """

    def __init__(self, entity: "Entity", from: "Location", to: "Location"):
        ...


    def __init__(self, entity: "Entity", from: "Location", to: "Location", searchRadius: int):
        ...


    def setSearchRadius(self, searchRadius: int) -> None:
        """
        Set the Block radius to search in for available portals.

        Arguments
        - searchRadius: the radius in which to search for a portal from the
        location
        """
        ...


    def getSearchRadius(self) -> int:
        """
        Gets the search radius value for finding an available portal.

        Returns
        - the currently set search radius
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.entity.Ghast

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Ghast(Flying, Enemy):
    """
    Represents a Ghast.
    """

    def isCharging(self) -> bool:
        """
        Gets whether the Ghast is charging

        Returns
        - Whether the Ghast is charging
        """
        ...


    def setCharging(self, flag: bool) -> None:
        """
        Sets whether the Ghast is charging

        Arguments
        - flag: Whether the Ghast is charging
        """
        ...



from .ServerOperator import ServerOperator
from .PermissionAttachment import PermissionAttachment
from .Permissible import Permissible
from .Permission import Permission
from .PermissionAttachmentInfo import PermissionAttachmentInfo
from .PermissibleBase import PermissibleBase
from .PermissionRemovedExecutor import PermissionRemovedExecutor
from .PermissionDefault import PermissionDefault


"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedMultisetFauxverideShim

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import DoNotCall
from java.util.function import Function
from java.util.function import ToIntFunction
from java.util.stream import Collector
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedMultisetFauxverideShim(ImmutableMultiset):
    """
    "Overrides" the ImmutableMultiset static methods that lack ImmutableSortedMultiset equivalents with deprecated, exception-throwing versions. This prevents
    accidents like the following:
    
    ````List<Object> objects = ...;
    // Sort them:
    Set<Object> sorted = ImmutableSortedMultiset.copyOf(objects);
    // BAD CODE! The returned multiset is actually an unsorted ImmutableMultiset!````
    
    While we could put the overrides in ImmutableSortedMultiset itself, it seems clearer
    to separate these "do not call" methods from those intended for normal use.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def toImmutableMultiset() -> "Collector"["E", Any, "ImmutableMultiset"["E"]]:
        """
        Not supported. Use ImmutableSortedMultiset.toImmutableSortedMultiset instead. This
        method exists only to hide ImmutableMultiset.toImmutableMultiset from consumers of
        `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 21.0

        Deprecated
        - Use ImmutableSortedMultiset.toImmutableSortedMultiset.
        """
        ...


    @staticmethod
    def toImmutableMultiset(elementFunction: "Function"["T", "E"], countFunction: "ToIntFunction"["T"]) -> "Collector"["T", Any, "ImmutableMultiset"["E"]]:
        """
        Not supported. Use ImmutableSortedMultiset.toImmutableSortedMultiset instead. This
        method exists only to hide ImmutableMultiset.toImmutableMultiset from consumers of
        `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 22.0

        Deprecated
        - Use ImmutableSortedMultiset.toImmutableSortedMultiset.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedMultiset.Builder"["E"]:
        """
        Not supported. Use ImmutableSortedMultiset.naturalOrder, which offers better
        type-safety, instead. This method exists only to hide ImmutableMultiset.builder from
        consumers of `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMultiset.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def of(element: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a parameter of type `Comparable` to use ImmutableSortedMultiset.of(Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable, Comparable) .
            **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable, Comparable,
            Comparable, Comparable...) . **
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain non-`Comparable` elements.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass parameters of type `Comparable` to use ImmutableSortedMultiset.copyOf(Comparable[]).**
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.SingletonImmutableSet

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Preconditions
from com.google.common.collect import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SingletonImmutableSet(ImmutableSet):
    """
    Implementation of ImmutableSet with exactly one element.

    Author(s)
    - Nick Kralevich
    """

    def size(self) -> int:
        ...


    def contains(self, target: "Object") -> bool:
        ...


    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def asList(self) -> "ImmutableList"["E"]:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.LecternInventory

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Lectern
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class LecternInventory(Inventory):
    """
    Interface to the inventory of a Lectern.
    """

    def getHolder(self) -> "Lectern":
        ...



from .BlockEvent import BlockEvent
from .BlockExplodeEvent import BlockExplodeEvent
from .BlockExpEvent import BlockExpEvent
from .BlockFormEvent import BlockFormEvent
from .BlockShearEntityEvent import BlockShearEntityEvent
from .BlockCookEvent import BlockCookEvent
from .BlockGrowEvent import BlockGrowEvent
from .MoistureChangeEvent import MoistureChangeEvent
from .CauldronLevelChangeEvent import CauldronLevelChangeEvent
from .BlockPistonRetractEvent import BlockPistonRetractEvent
from .LeavesDecayEvent import LeavesDecayEvent
from .BlockReceiveGameEvent import BlockReceiveGameEvent
from .BellRingEvent import BellRingEvent
from .BlockSpreadEvent import BlockSpreadEvent
from .BlockFertilizeEvent import BlockFertilizeEvent
from .BlockMultiPlaceEvent import BlockMultiPlaceEvent
from .SignChangeEvent import SignChangeEvent
from .BlockDispenseArmorEvent import BlockDispenseArmorEvent
from .BlockPhysicsEvent import BlockPhysicsEvent
from .BlockDropItemEvent import BlockDropItemEvent
from .EntityBlockFormEvent import EntityBlockFormEvent
from .Action import Action
from .SculkBloomEvent import SculkBloomEvent
from .BlockPistonEvent import BlockPistonEvent
from .BlockRedstoneEvent import BlockRedstoneEvent
from .BlockPlaceEvent import BlockPlaceEvent
from .NotePlayEvent import NotePlayEvent
from .BlockIgniteEvent import BlockIgniteEvent
from .SpongeAbsorbEvent import SpongeAbsorbEvent
from .InventoryBlockStartEvent import InventoryBlockStartEvent
from .BlockCanBuildEvent import BlockCanBuildEvent
from .TNTPrimeEvent import TNTPrimeEvent
from .BlockBurnEvent import BlockBurnEvent
from .BlockDamageAbortEvent import BlockDamageAbortEvent
from .BlockFromToEvent import BlockFromToEvent
from .CampfireStartEvent import CampfireStartEvent
from .BlockPistonExtendEvent import BlockPistonExtendEvent
from .BlockBreakEvent import BlockBreakEvent
from .BrewingStartEvent import BrewingStartEvent
from .BellResonateEvent import BellResonateEvent
from .BlockFadeEvent import BlockFadeEvent
from .BlockDamageEvent import BlockDamageEvent
from .BlockDispenseEvent import BlockDispenseEvent
from .FluidLevelChangeEvent import FluidLevelChangeEvent


"""
Python module generated from Java source file com.google.gson.reflect.TypeToken

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import $Gson$Types
from com.google.gson.reflect import *
from java.lang.reflect import GenericArrayType
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from java.lang.reflect import TypeVariable
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class TypeToken:
    """
    Represents a generic type `T`. Java doesn't yet provide a way to
    represent generic types, so this class does. Forces clients to create a
    subclass of this class which enables retrieval the type information even at
    runtime.
    
    For example, to create a type literal for `List<String>`, you can
    create an empty anonymous class:
    
    
    `TypeToken<List<String>> list = new TypeToken<List<String>>() {`;}
    
    Capturing a type variable as type argument of a `TypeToken` should
    be avoided. Due to type erasure the runtime type of a type variable is not
    available to Gson and therefore it cannot provide the functionality one
    might expect, which gives a False sense of type-safety at compilation time
    and can lead to an unexpected `ClassCastException` at runtime.
    
    If the type arguments of the parameterized type are only available at
    runtime, for example when you want to create a `List<E>` based on
    a `Class<E>` representing the element type, the method
    .getParameterized(Type, Type...) can be used.

    Author(s)
    - Jesse Wilson
    """

    def getRawType(self) -> type["T"]:
        """
        Returns the raw (non-generic) type for this type.
        """
        ...


    def getType(self) -> "Type":
        """
        Gets underlying `Type` instance.
        """
        ...


    def isAssignableFrom(self, cls: type[Any]) -> bool:
        """
        Check if this type is assignable from the given class object.

        Deprecated
        - this implementation may be inconsistent with javac for types
            with wildcards.
        """
        ...


    def isAssignableFrom(self, from: "Type") -> bool:
        """
        Check if this type is assignable from the given Type.

        Deprecated
        - this implementation may be inconsistent with javac for types
            with wildcards.
        """
        ...


    def isAssignableFrom(self, token: "TypeToken"[Any]) -> bool:
        """
        Check if this type is assignable from the given type token.

        Deprecated
        - this implementation may be inconsistent with javac for types
            with wildcards.
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, o: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def get(type: "Type") -> "TypeToken"[Any]:
        """
        Gets type literal for the given `Type` instance.
        """
        ...


    @staticmethod
    def get(type: type["T"]) -> "TypeToken"["T"]:
        """
        Gets type literal for the given `Class` instance.
        """
        ...


    @staticmethod
    def getParameterized(rawType: "Type", *typeArguments: Tuple["Type", ...]) -> "TypeToken"[Any]:
        """
        Gets a type literal for the parameterized type represented by applying `typeArguments` to
        `rawType`. This is mainly intended for situations where the type arguments are not
        available at compile time. The following example shows how a type token for `Map<K, V>`
        can be created:
        ````Class<K> keyClass = ...;
        Class<V> valueClass = ...;
        TypeToken<?> mapTypeToken = TypeToken.getParameterized(Map.class, keyClass, valueClass);````
        As seen here the result is a `TypeToken<?>`; this method cannot provide any type safety,
        and care must be taken to pass in the correct number of type arguments.

        Raises
        - IllegalArgumentException: If `rawType` is not of type `Class`, or if the type arguments are invalid for
          the raw type
        """
        ...


    @staticmethod
    def getArray(componentType: "Type") -> "TypeToken"[Any]:
        """
        Gets type literal for the array type whose elements are all instances of `componentType`.
        """
        ...



from .ExclusionStrategy import ExclusionStrategy
from .FieldNamingStrategy import FieldNamingStrategy
from .JsonStreamParser import JsonStreamParser
from .InstanceCreator import InstanceCreator
from .TypeAdapterFactory import TypeAdapterFactory
from .JsonParseException import JsonParseException
from .JsonSerializationContext import JsonSerializationContext
from .JsonParser import JsonParser
from .JsonSyntaxException import JsonSyntaxException
from .ToNumberPolicy import ToNumberPolicy
from .JsonPrimitive import JsonPrimitive
from .TypeAdapter import TypeAdapter
from .Gson import Gson
from .JsonSerializer import JsonSerializer
from .FieldAttributes import FieldAttributes
from .JsonIOException import JsonIOException
from .JsonObject import JsonObject
from .FieldNamingPolicy import FieldNamingPolicy
from .JsonNull import JsonNull
from .GsonBuilder import GsonBuilder
from .JsonDeserializationContext import JsonDeserializationContext
from .LongSerializationPolicy import LongSerializationPolicy
from .JsonDeserializer import JsonDeserializer
from .ReflectionAccessFilter import ReflectionAccessFilter
from .JsonElement import JsonElement
from .ToNumberStrategy import ToNumberStrategy
from .JsonArray import JsonArray


"""
Python module generated from Java source file com.google.gson.TypeAdapterFactory

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.reflect import TypeToken
from typing import Any, Callable, Iterable, Tuple


class TypeAdapterFactory:
    """
    Creates type adapters for set of related types. Type adapter factories are
    most useful when several types share similar structure in their JSON form.
    
    <h2>Examples</h2>
    <h3>Example: Converting enums to lowercase</h3>
    In this example, we implement a factory that creates type adapters for all
    enums. The type adapters will write enums in lowercase, despite the fact
    that they're defined in `CONSTANT_CASE` in the corresponding Java
    model: ```   `public class LowercaseEnumTypeAdapterFactory implements TypeAdapterFactory {
        public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
          Class<T> rawType = (Class<T>) type.getRawType();
          if (!rawType.isEnum()) {
            return null;`
    
          final Map<String, T> lowercaseToConstant = new HashMap<>();
          for (T constant : rawType.getEnumConstants()) {
            lowercaseToConstant.put(toLowercase(constant), constant);
          }
    
          return new TypeAdapter<T>() {
            public void write(JsonWriter out, T value) throws IOException {
              if (value == null) {
                out.nullValue();
              } else {
                out.value(toLowercase(value));
              }
            }
    
            public T read(JsonReader reader) throws IOException {
              if (reader.peek() == JsonToken.NULL) {
                reader.nextNull();
                return null;
              } else {
                return lowercaseToConstant.get(reader.nextString());
              }
            }
          };
        }
    
        private String toLowercase(Object o) {
          return o.toString().toLowerCase(Locale.US);
        }
      }
    }```
    
    Type adapter factories select which types they provide type adapters
    for. If a factory cannot support a given type, it must return null when
    that type is passed to .create. Factories should expect `create()` to be called on them for many types and should return null for
    most of those types. In the above example the factory returns null for
    calls to `create()` where `type` is not an enum.
    
    A factory is typically called once per type, but the returned type
    adapter may be used many times. It is most efficient to do expensive work
    like reflection in `create()` so that the type adapter's `read()` and `write()` methods can be very fast. In this example the
    mapping from lowercase name to enum value is computed eagerly.
    
    As with type adapters, factories must be *registered* with a com.google.gson.GsonBuilder for them to take effect: ```   `GsonBuilder builder = new GsonBuilder();
     builder.registerTypeAdapterFactory(new LowercaseEnumTypeAdapterFactory());
     ...
     Gson gson = builder.create();````
    If multiple factories support the same type, the factory registered earlier
    takes precedence.
    
    <h3>Example: Composing other type adapters</h3>
    In this example we implement a factory for Guava's `Multiset`
    collection type. The factory can be used to create type adapters for
    multisets of any element type: the type adapter for `Multiset<String>` is different from the type adapter for `Multiset<URL>`.
    
    The type adapter *delegates* to another type adapter for the
    multiset elements. It figures out the element type by reflecting on the
    multiset's type token. A `Gson` is passed in to `create` for
    just this purpose: ```   `public class MultisetTypeAdapterFactory implements TypeAdapterFactory {
        public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> typeToken) {
          Type type = typeToken.getType();
          if (typeToken.getRawType() != Multiset.class
              || !(type instanceof ParameterizedType)) {
            return null;`
    
          Type elementType = ((ParameterizedType) type).getActualTypeArguments()[0];
          TypeAdapter<?> elementAdapter = gson.getAdapter(TypeToken.get(elementType));
          return (TypeAdapter<T>) newMultisetAdapter(elementAdapter);
        }
    
        private <E> TypeAdapter<Multiset<E>> newMultisetAdapter(
            final TypeAdapter<E> elementAdapter) {
          return new TypeAdapter<Multiset<E>>() {
            public void write(JsonWriter out, Multiset<E> value) throws IOException {
              if (value == null) {
                out.nullValue();
                return;
              }
    
              out.beginArray();
              for (Multiset.Entry<E> entry : value.entrySet()) {
                out.value(entry.getCount());
                elementAdapter.write(out, entry.getElement());
              }
              out.endArray();
            }
    
            public Multiset<E> read(JsonReader in) throws IOException {
              if (in.peek() == JsonToken.NULL) {
                in.nextNull();
                return null;
              }
    
              Multiset<E> result = LinkedHashMultiset.create();
              in.beginArray();
              while (in.hasNext()) {
                int count = in.nextInt();
                E element = elementAdapter.read(in);
                result.add(element, count);
              }
              in.endArray();
              return result;
            }
          };
        }
      }
    }```
    Delegating from one type adapter to another is extremely powerful; it's
    the foundation of how Gson converts Java objects and collections. Whenever
    possible your factory should retrieve its delegate type adapter in the
    `create()` method; this ensures potentially-expensive type adapter
    creation happens only once.

    Since
    - 2.1
    """

    def create(self, gson: "Gson", type: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        """
        Returns a type adapter for `type`, or null if this factory doesn't
        support `type`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.banner.Pattern

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableMap
from java.util import NoSuchElementException
from org.bukkit import DyeColor
from org.bukkit.block.banner import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import SerializableAs
from typing import Any, Callable, Iterable, Tuple


class Pattern(ConfigurationSerializable):

    def __init__(self, color: "DyeColor", pattern: "PatternType"):
        """
        Creates a new pattern from the specified color and
        pattern type

        Arguments
        - color: the pattern color
        - pattern: the pattern type
        """
        ...


    def __init__(self, map: dict[str, "Object"]):
        """
        Constructor for deserialization.

        Arguments
        - map: the map to deserialize from
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    def getColor(self) -> "DyeColor":
        """
        Returns the color of the pattern

        Returns
        - the color of the pattern
        """
        ...


    def getPattern(self) -> "PatternType":
        """
        Returns the type of pattern

        Returns
        - the pattern type
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



from .ConfigurationSerializable import ConfigurationSerializable
from .SerializableAs import SerializableAs
from .ConfigurationSerialization import ConfigurationSerialization
from .DelegateDeserialization import DelegateDeserialization


"""
Python module generated from Java source file com.google.common.util.concurrent.ExecutionError

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ExecutionError(Error):
    """
    Error variant of java.util.concurrent.ExecutionException. As with `ExecutionException`, the error's .getCause() cause comes from a failed task,
    possibly run in another thread. That cause should itself be an `Error`; if not, use `ExecutionException` or UncheckedExecutionException. This allows the client code to
    continue to distinguish between exceptions and errors, even when they come from other threads.

    Author(s)
    - Chris Povirk

    Since
    - 10.0
    """

    def __init__(self, message: str, cause: "Error"):
        """
        Creates a new instance with the given detail message and cause.
        """
        ...


    def __init__(self, cause: "Error"):
        """
        Creates a new instance with the given cause.
        """
        ...



"""
Python module generated from Java source file org.bukkit.potion.PotionType

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Suppliers
from enum import Enum
from java.util.function import Supplier
from org.bukkit import Bukkit
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class PotionType(Enum):
    """
    This enum reflects and matches each potion state that can be obtained from
    the Creative mode inventory
    """

    UNCRAFTABLE = ("empty")
    WATER = ("water")
    MUNDANE = ("mundane")
    THICK = ("thick")
    AWKWARD = ("awkward")
    NIGHT_VISION = ("night_vision")
    LONG_NIGHT_VISION = ("long_night_vision")
    INVISIBILITY = ("invisibility")
    LONG_INVISIBILITY = ("long_invisibility")
    JUMP = ("leaping")
    LONG_LEAPING = ("long_leaping")
    STRONG_LEAPING = ("strong_leaping")
    FIRE_RESISTANCE = ("fire_resistance")
    LONG_FIRE_RESISTANCE = ("long_fire_resistance")
    SPEED = ("swiftness")
    LONG_SWIFTNESS = ("long_swiftness")
    STRONG_SWIFTNESS = ("strong_swiftness")
    SLOWNESS = ("slowness")
    LONG_SLOWNESS = ("long_slowness")
    STRONG_SLOWNESS = ("strong_slowness")
    WATER_BREATHING = ("water_breathing")
    LONG_WATER_BREATHING = ("long_water_breathing")
    INSTANT_HEAL = ("healing")
    STRONG_HEALING = ("strong_healing")
    INSTANT_DAMAGE = ("harming")
    STRONG_HARMING = ("strong_harming")
    POISON = ("poison")
    LONG_POISON = ("long_poison")
    STRONG_POISON = ("strong_poison")
    REGEN = ("regeneration")
    LONG_REGENERATION = ("long_regeneration")
    STRONG_REGENERATION = ("strong_regeneration")
    STRENGTH = ("strength")
    LONG_STRENGTH = ("long_strength")
    STRONG_STRENGTH = ("strong_strength")
    WEAKNESS = ("weakness")
    LONG_WEAKNESS = ("long_weakness")
    LUCK = ("luck")
    TURTLE_MASTER = ("turtle_master")
    LONG_TURTLE_MASTER = ("long_turtle_master")
    STRONG_TURTLE_MASTER = ("strong_turtle_master")
    SLOW_FALLING = ("slow_falling")
    LONG_SLOW_FALLING = ("long_slow_falling")


    def getEffectType(self) -> "PotionEffectType":
        """
        Returns
        - the potion effect type of this potion type

        Deprecated
        - Potions can have multiple effects use .getPotionEffects()
        """
        ...


    def getPotionEffects(self) -> list["PotionEffect"]:
        """
        Returns
        - a list of all effects this potion type has
        """
        ...


    def isInstant(self) -> bool:
        """
        Returns
        - if this potion type is instant

        Deprecated
        - PotionType can have multiple effects, some of which can be instant and others not.
        Use PotionEffectType.isInstant() in combination with .getPotionEffects() and PotionEffect.getType()
        """
        ...


    def isUpgradeable(self) -> bool:
        """
        Checks if the potion type has an upgraded state.
        This refers to whether or not the potion type can be Tier 2,
        such as Potion of Fire Resistance II.

        Returns
        - True if the potion type can be upgraded;
        """
        ...


    def isExtendable(self) -> bool:
        """
        Checks if the potion type has an extended state.
        This refers to the extended duration potions

        Returns
        - True if the potion type can be extended
        """
        ...


    def getMaxLevel(self) -> int:
        ...


    @staticmethod
    def getByEffect(effectType: "PotionEffectType") -> "PotionType":
        """
        Arguments
        - effectType: the effect to get by

        Returns
        - the matching potion type

        Deprecated
        - Misleading
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    class InternalPotionData:
        """
        Deprecated
        - Do not use, interface will get removed, and the plugin won't run
        """

        def getEffectType(self) -> "PotionEffectType":
            ...


        def getPotionEffects(self) -> list["PotionEffect"]:
            ...


        def isInstant(self) -> bool:
            ...


        def isUpgradeable(self) -> bool:
            ...


        def isExtendable(self) -> bool:
            ...


        def getMaxLevel(self) -> int:
            ...



from .VehicleDamageEvent import VehicleDamageEvent
from .VehicleExitEvent import VehicleExitEvent
from .VehicleMoveEvent import VehicleMoveEvent
from .VehicleEnterEvent import VehicleEnterEvent
from .VehicleEntityCollisionEvent import VehicleEntityCollisionEvent
from .VehicleUpdateEvent import VehicleUpdateEvent
from .VehicleEvent import VehicleEvent
from .VehicleDestroyEvent import VehicleDestroyEvent
from .VehicleBlockCollisionEvent import VehicleBlockCollisionEvent
from .VehicleCreateEvent import VehicleCreateEvent
from .VehicleCollisionEvent import VehicleCollisionEvent


"""
Python module generated from Java source file com.google.common.collect.ImmutableAsList

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableAsList(ImmutableList):
    """
    List returned by ImmutableCollection.asList that delegates `contains` checks to the
    backing collection.

    Author(s)
    - Louis Wasserman
    """

    def contains(self, target: "Object") -> bool:
        ...


    def size(self) -> int:
        ...


    def isEmpty(self) -> bool:
        ...



from .EntityBreakDoorEvent import EntityBreakDoorEvent
from .ItemSpawnEvent import ItemSpawnEvent
from .HorseJumpEvent import HorseJumpEvent
from .EntityEnterBlockEvent import EntityEnterBlockEvent
from .AreaEffectCloudApplyEvent import AreaEffectCloudApplyEvent
from .EntityKnockbackByEntityEvent import EntityKnockbackByEntityEvent
from .PigZombieAngerEvent import PigZombieAngerEvent
from .FireworkExplodeEvent import FireworkExplodeEvent
from .EntityRegainHealthEvent import EntityRegainHealthEvent
from .EntityPortalExitEvent import EntityPortalExitEvent
from .CreatureSpawnEvent import CreatureSpawnEvent
from .EntityPickupItemEvent import EntityPickupItemEvent
from .LingeringPotionSplashEvent import LingeringPotionSplashEvent
from .VillagerReplenishTradeEvent import VillagerReplenishTradeEvent
from .SheepDyeWoolEvent import SheepDyeWoolEvent
from .SpawnerSpawnEvent import SpawnerSpawnEvent
from .EntityEvent import EntityEvent
from .PotionSplashEvent import PotionSplashEvent
from .EntityChangeBlockEvent import EntityChangeBlockEvent
from .ItemDespawnEvent import ItemDespawnEvent
from .PlayerDeathEvent import PlayerDeathEvent
from .EntityTargetLivingEntityEvent import EntityTargetLivingEntityEvent
from .EntityBreedEvent import EntityBreedEvent
from .VillagerCareerChangeEvent import VillagerCareerChangeEvent
from .EntityCombustEvent import EntityCombustEvent
from .EntityPlaceEvent import EntityPlaceEvent
from .CreeperPowerEvent import CreeperPowerEvent
from .EntityToggleGlideEvent import EntityToggleGlideEvent
from .EntityTameEvent import EntityTameEvent
from .EntityUnleashEvent import EntityUnleashEvent
from .EntityEnterLoveModeEvent import EntityEnterLoveModeEvent
from .EntityAirChangeEvent import EntityAirChangeEvent
from .FoodLevelChangeEvent import FoodLevelChangeEvent
from .EntityDismountEvent import EntityDismountEvent
from .EntityShootBowEvent import EntityShootBowEvent
from .EntitySpawnEvent import EntitySpawnEvent
from .SlimeSplitEvent import SlimeSplitEvent
from .ProjectileHitEvent import ProjectileHitEvent
from .EntityToggleSwimEvent import EntityToggleSwimEvent
from .EntityExplodeEvent import EntityExplodeEvent
from .PlayerLeashEntityEvent import PlayerLeashEntityEvent
from .EnderDragonChangePhaseEvent import EnderDragonChangePhaseEvent
from .EntityTransformEvent import EntityTransformEvent
from .EntityTeleportEvent import EntityTeleportEvent
from .StriderTemperatureChangeEvent import StriderTemperatureChangeEvent
from .ExplosionPrimeEvent import ExplosionPrimeEvent
from .PigZapEvent import PigZapEvent
from .EntityKnockbackEvent import EntityKnockbackEvent
from .EntityTargetEvent import EntityTargetEvent
from .EntityResurrectEvent import EntityResurrectEvent
from .EntityPortalEnterEvent import EntityPortalEnterEvent
from .EntityDeathEvent import EntityDeathEvent
from .EntityDamageEvent import EntityDamageEvent
from .EntityMountEvent import EntityMountEvent
from .EntityRemoveEvent import EntityRemoveEvent
from .EntityDamageByBlockEvent import EntityDamageByBlockEvent
from .SheepRegrowWoolEvent import SheepRegrowWoolEvent
from .PiglinBarterEvent import PiglinBarterEvent
from .ExpBottleEvent import ExpBottleEvent
from .EntitySpellCastEvent import EntitySpellCastEvent
from .EntityExhaustionEvent import EntityExhaustionEvent
from .EntityPoseChangeEvent import EntityPoseChangeEvent
from .EntityCreatePortalEvent import EntityCreatePortalEvent
from .ProjectileLaunchEvent import ProjectileLaunchEvent
from .VillagerAcquireTradeEvent import VillagerAcquireTradeEvent
from .EntityDamageByEntityEvent import EntityDamageByEntityEvent
from .EntityCombustByEntityEvent import EntityCombustByEntityEvent
from .ItemMergeEvent import ItemMergeEvent
from .EntityPortalEvent import EntityPortalEvent
from .EntityInteractEvent import EntityInteractEvent
from .ArrowBodyCountChangeEvent import ArrowBodyCountChangeEvent
from .BatToggleSleepEvent import BatToggleSleepEvent
from .EntityDropItemEvent import EntityDropItemEvent
from .EntityPotionEffectEvent import EntityPotionEffectEvent
from .EntityCombustByBlockEvent import EntityCombustByBlockEvent


from .ConfigurationSection import ConfigurationSection
from .MemoryConfigurationOptions import MemoryConfigurationOptions
from .InvalidConfigurationException import InvalidConfigurationException
from .Configuration import Configuration
from .MemoryConfiguration import MemoryConfiguration
from .MemorySection import MemorySection
from .SectionPathData import SectionPathData
from .ConfigurationOptions import ConfigurationOptions


"""
Python module generated from Java source file org.bukkit.event.entity.EntitySpellCastEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Spellcaster
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntitySpellCastEvent(EntityEvent, Cancellable):
    """
    Called when a Spellcaster casts a spell.
    """

    def __init__(self, what: "Spellcaster", spell: "Spellcaster.Spell"):
        ...


    def getEntity(self) -> "Spellcaster":
        ...


    def getSpell(self) -> "Spellcaster.Spell":
        """
        Get the spell to be cast in this event.
        
        This is a convenience method equivalent to
        Spellcaster.getSpell().

        Returns
        - the spell to cast
        """
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def isCancelled(self) -> bool:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.CreatureSpawner

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.block.spawner import SpawnRule
from org.bukkit.block.spawner import SpawnerEntry
from org.bukkit.entity import EntitySnapshot
from org.bukkit.entity import EntityType
from typing import Any, Callable, Iterable, Tuple


class CreatureSpawner(TileState):
    """
    Represents a captured state of a creature spawner.
    """

    def getSpawnedType(self) -> "EntityType":
        """
        Get the spawner's creature type.

        Returns
        - The creature type or null if it not set.
        """
        ...


    def setSpawnedType(self, creatureType: "EntityType") -> None:
        """
        Set the spawner's creature type. 
        This will override any entities that have been added with .addPotentialSpawn

        Arguments
        - creatureType: The creature type or null to clear.
        """
        ...


    def setCreatureTypeByName(self, creatureType: str) -> None:
        """
        Set the spawner mob type.

        Arguments
        - creatureType: The creature type's name or null to clear.

        Deprecated
        - magic value, use
        .setSpawnedType(org.bukkit.entity.EntityType).
        """
        ...


    def getCreatureTypeName(self) -> str:
        """
        Get the spawner's creature type.

        Returns
        - The creature type's name if is set.

        Deprecated
        - magic value, use .getSpawnedType().
        """
        ...


    def getDelay(self) -> int:
        """
        Get the spawner's delay.
        
        This is the delay, in ticks, until the spawner will spawn its next mob.

        Returns
        - The delay.
        """
        ...


    def setDelay(self, delay: int) -> None:
        """
        Set the spawner's delay.
        
        If set to -1, the spawn delay will be reset to a random value between
        .getMinSpawnDelay and .getMaxSpawnDelay().

        Arguments
        - delay: The delay.
        """
        ...


    def getMinSpawnDelay(self) -> int:
        """
        The minimum spawn delay amount (in ticks).
        
        This value is used when the spawner resets its delay (for any reason).
        It will choose a random number between .getMinSpawnDelay()
        and .getMaxSpawnDelay() for its next .getDelay().
        
        Default value is 200 ticks.

        Returns
        - the minimum spawn delay amount
        """
        ...


    def setMinSpawnDelay(self, delay: int) -> None:
        """
        Set the minimum spawn delay amount (in ticks).

        Arguments
        - delay: the minimum spawn delay amount

        See
        - .getMinSpawnDelay()
        """
        ...


    def getMaxSpawnDelay(self) -> int:
        """
        The maximum spawn delay amount (in ticks).
        
        This value is used when the spawner resets its delay (for any reason).
        It will choose a random number between .getMinSpawnDelay()
        and .getMaxSpawnDelay() for its next .getDelay().
        
        This value **must** be greater than 0 and less than or equal to
        .getMaxSpawnDelay().
        
        Default value is 800 ticks.

        Returns
        - the maximum spawn delay amount
        """
        ...


    def setMaxSpawnDelay(self, delay: int) -> None:
        """
        Set the maximum spawn delay amount (in ticks).
        
        This value **must** be greater than 0, as well as greater than or
        equal to .getMinSpawnDelay()

        Arguments
        - delay: the new maximum spawn delay amount

        See
        - .getMaxSpawnDelay()
        """
        ...


    def getSpawnCount(self) -> int:
        """
        Get how many mobs attempt to spawn.
        
        Default value is 4.

        Returns
        - the current spawn count
        """
        ...


    def setSpawnCount(self, spawnCount: int) -> None:
        """
        Set how many mobs attempt to spawn.

        Arguments
        - spawnCount: the new spawn count
        """
        ...


    def getMaxNearbyEntities(self) -> int:
        """
        Set the new maximum amount of similar entities that are allowed to be
        within spawning range of this spawner.
        
        If more than the maximum number of entities are within range, the spawner
        will not spawn and try again with a new .getDelay().
        
        Default value is 16.

        Returns
        - the maximum number of nearby, similar, entities
        """
        ...


    def setMaxNearbyEntities(self, maxNearbyEntities: int) -> None:
        """
        Set the maximum number of similar entities that are allowed to be within
        spawning range of this spawner.
        
        Similar entities are entities that are of the same EntityType

        Arguments
        - maxNearbyEntities: the maximum number of nearby, similar, entities
        """
        ...


    def getRequiredPlayerRange(self) -> int:
        """
        Get the maximum distance(squared) a player can be in order for this
        spawner to be active.
        
        If this value is less than or equal to 0, this spawner is always active
        (given that there are players online).
        
        Default value is 16.

        Returns
        - the maximum distance(squared) a player can be in order for this
        spawner to be active.
        """
        ...


    def setRequiredPlayerRange(self, requiredPlayerRange: int) -> None:
        """
        Set the maximum distance (squared) a player can be in order for this
        spawner to be active.
        
        Setting this value to less than or equal to 0 will make this spawner
        always active (given that there are players online).

        Arguments
        - requiredPlayerRange: the maximum distance (squared) a player can be
        in order for this spawner to be active.
        """
        ...


    def getSpawnRange(self) -> int:
        """
        Get the radius around which the spawner will attempt to spawn mobs in.
        
        This area is square, includes the block the spawner is in, and is
        centered on the spawner's x,z coordinates - not the spawner itself.
        
        It is 2 blocks high, centered on the spawner's y-coordinate (its bottom);
        thus allowing mobs to spawn as high as its top surface and as low
        as 1 block below its bottom surface.
        
        Default value is 4.

        Returns
        - the spawn range
        """
        ...


    def setSpawnRange(self, spawnRange: int) -> None:
        """
        Set the new spawn range.

        Arguments
        - spawnRange: the new spawn range

        See
        - .getSpawnRange()
        """
        ...


    def getSpawnedEntity(self) -> "EntitySnapshot":
        """
        Gets the EntitySnapshot that will be spawned by this spawner or null
        if no entities have been assigned to this spawner. 
        
        All applicable data from the spawner will be copied, such as custom name,
        health, and velocity. 

        Returns
        - the entity snapshot or null if no entities have been assigned to this
                spawner.
        """
        ...


    def setSpawnedEntity(self, snapshot: "EntitySnapshot") -> None:
        """
        Sets the entity that will be spawned by this spawner. 
        This will override any previous entries that have been added with
        .addPotentialSpawn
        
        All applicable data from the snapshot will be copied, such as custom name,
        health, and velocity. 

        Arguments
        - snapshot: the entity snapshot
        """
        ...


    def addPotentialSpawn(self, snapshot: "EntitySnapshot", weight: int, spawnRule: "SpawnRule") -> None:
        """
        Adds a new EntitySnapshot to the list of entities this spawner can
        spawn.
        
        The weight will determine how often this entry is chosen to spawn, higher
        weighted entries will spawn more often than lower weighted ones. 
        The SpawnRule will determine under what conditions this entry can
        spawn, passing null will use the default conditions for the given entity.

        Arguments
        - snapshot: the snapshot that will be spawned
        - weight: the weight
        - spawnRule: the spawn rule for this entity, or null
        """
        ...


    def addPotentialSpawn(self, spawnerEntry: "SpawnerEntry") -> None:
        """
        Adds a new SpawnerEntry to the list of entities this spawner can
        spawn. 

        Arguments
        - spawnerEntry: the spawner entry to use

        See
        - .addPotentialSpawn(EntitySnapshot, int, SpawnRule)
        """
        ...


    def setPotentialSpawns(self, entries: Iterable["SpawnerEntry"]) -> None:
        """
        Sets the list of SpawnerEntry this spawner can spawn. 
        This will override any previous entries added with
        .addPotentialSpawn

        Arguments
        - entries: the list of entries
        """
        ...


    def getPotentialSpawns(self) -> list["SpawnerEntry"]:
        """
        Gets a list of potential spawns from this spawner or an empty list if no
        entities have been assigned to this spawner. 
        Changes made to the returned list will not be reflected in the spawner unless
        applied with .setPotentialSpawns

        Returns
        - a list of potential spawns from this spawner, or an empty list if no
                entities have been assigned to this spawner

        See
        - .getSpawnedType()
        """
        ...



from .GsonBuildConfig import GsonBuildConfig
from .Primitives import Primitives
from .Streams import Streams
from .ConstructorConstructor import ConstructorConstructor
from .$Gson$Types import $Gson$Types
from .ReflectionAccessFilterHelper import ReflectionAccessFilterHelper
from .JavaVersion import JavaVersion
from .Excluder import Excluder
from .$Gson$Preconditions import $Gson$Preconditions
from .JsonReaderInternalAccess import JsonReaderInternalAccess
from .NonNullElementWrapperList import NonNullElementWrapperList
from .ObjectConstructor import ObjectConstructor
from .UnsafeAllocator import UnsafeAllocator
from .LazilyParsedNumber import LazilyParsedNumber
from .PreJava9DateFormatProvider import PreJava9DateFormatProvider
from .LinkedTreeMap import LinkedTreeMap


"""
Python module generated from Java source file org.bukkit.material.Stairs

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Stairs(MaterialData, Directional):
    """
    Represents stairs.

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getAscendingDirection(self) -> "BlockFace":
        """
        Returns
        - the direction the stairs ascend towards
        """
        ...


    def getDescendingDirection(self) -> "BlockFace":
        """
        Returns
        - the direction the stairs descend towards
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        """
        Set the direction the stair part of the block is facing
        """
        ...


    def getFacing(self) -> "BlockFace":
        """
        Returns
        - the direction the stair part of the block is facing
        """
        ...


    def isInverted(self) -> bool:
        """
        Test if step is inverted

        Returns
        - True if inverted (top half), False if normal (bottom half)
        """
        ...


    def setInverted(self, inv: bool) -> None:
        """
        Set step inverted state

        Arguments
        - inv: - True if step is inverted (top half), False if step is
            normal (bottom half)
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Stairs":
        ...



"""
Python module generated from Java source file org.bukkit.block.banner.PatternType

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.block.banner import *
from typing import Any, Callable, Iterable, Tuple


class PatternType(Enum):

    BASE = ("b", "base")
    SQUARE_BOTTOM_LEFT = ("bl", "square_bottom_left")
    SQUARE_BOTTOM_RIGHT = ("br", "square_bottom_right")
    SQUARE_TOP_LEFT = ("tl", "square_top_left")
    SQUARE_TOP_RIGHT = ("tr", "square_top_right")
    STRIPE_BOTTOM = ("bs", "stripe_bottom")
    STRIPE_TOP = ("ts", "stripe_top")
    STRIPE_LEFT = ("ls", "stripe_left")
    STRIPE_RIGHT = ("rs", "stripe_right")
    STRIPE_CENTER = ("cs", "stripe_center")
    STRIPE_MIDDLE = ("ms", "stripe_middle")
    STRIPE_DOWNRIGHT = ("drs", "stripe_downright")
    STRIPE_DOWNLEFT = ("dls", "stripe_downleft")
    STRIPE_SMALL = ("ss", "small_stripes")
    CROSS = ("cr", "cross")
    STRAIGHT_CROSS = ("sc", "straight_cross")
    TRIANGLE_BOTTOM = ("bt", "triangle_bottom")
    TRIANGLE_TOP = ("tt", "triangle_top")
    TRIANGLES_BOTTOM = ("bts", "triangles_bottom")
    TRIANGLES_TOP = ("tts", "triangles_top")
    DIAGONAL_LEFT = ("ld", "diagonal_left")
    DIAGONAL_RIGHT = ("rd", "diagonal_up_right")
    DIAGONAL_LEFT_MIRROR = ("lud", "diagonal_up_left")
    DIAGONAL_RIGHT_MIRROR = ("rud", "diagonal_right")
    CIRCLE_MIDDLE = ("mc", "circle")
    RHOMBUS_MIDDLE = ("mr", "rhombus")
    HALF_VERTICAL = ("vh", "half_vertical")
    HALF_HORIZONTAL = ("hh", "half_horizontal")
    HALF_VERTICAL_MIRROR = ("vhr", "half_vertical_right")
    HALF_HORIZONTAL_MIRROR = ("hhb", "half_horizontal_bottom")
    BORDER = ("bo", "border")
    CURLY_BORDER = ("cbo", "curly_border")
    CREEPER = ("cre", "creeper")
    GRADIENT = ("gra", "gradient")
    GRADIENT_UP = ("gru", "gradient_up")
    BRICKS = ("bri", "bricks")
    SKULL = ("sku", "skull")
    FLOWER = ("flo", "flower")
    MOJANG = ("moj", "mojang")
    GLOBE = ("glb", "globe")
    PIGLIN = ("pig", "piglin")


    def getKey(self) -> "NamespacedKey":
        ...


    def getIdentifier(self) -> str:
        """
        Returns the identifier used to represent
        this pattern type

        Returns
        - the pattern's identifier

        See
        - .getKey

        Deprecated
        - magic value
        """
        ...


    @staticmethod
    def getByIdentifier(identifier: str) -> "PatternType":
        """
        Returns the pattern type which matches the passed
        identifier or null if no matches are found

        Arguments
        - identifier: the identifier

        Returns
        - the matched pattern type or null

        See
        - Registry.BANNER_PATTERN

        Deprecated
        - magic value, use Registry.get(NamespacedKey) instead
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.DirectionalContainer

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class DirectionalContainer(MaterialData, Directional):
    """
    Represents a furnace or a dispenser.

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        ...


    def getFacing(self) -> "BlockFace":
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "DirectionalContainer":
        ...



"""
Python module generated from Java source file org.bukkit.block.Jigsaw

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Jigsaw(TileState):
    """
    Represents a captured state of a jigsaw.
    """





from .PerlinOctaveGenerator import PerlinOctaveGenerator
from .PerlinNoiseGenerator import PerlinNoiseGenerator
from .OctaveGenerator import OctaveGenerator
from .SimplexNoiseGenerator import SimplexNoiseGenerator
from .SimplexOctaveGenerator import SimplexOctaveGenerator
from .NoiseGenerator import NoiseGenerator


"""
Python module generated from Java source file org.bukkit.entity.Cat

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import DyeColor
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Cat(Tameable, Sittable):
    """
    Meow.
    """

    def getCatType(self) -> "Type":
        """
        Gets the current type of this cat.

        Returns
        - Type of the cat.
        """
        ...


    def setCatType(self, type: "Type") -> None:
        """
        Sets the current type of this cat.

        Arguments
        - type: New type of this cat.
        """
        ...


    def getCollarColor(self) -> "DyeColor":
        """
        Get the collar color of this cat

        Returns
        - the color of the collar
        """
        ...


    def setCollarColor(self, color: "DyeColor") -> None:
        """
        Set the collar color of this cat

        Arguments
        - color: the color to apply
        """
        ...


    class Type(Enum):
        """
        Represents the various different cat types there are.
        """

        TABBY = ("tabby")
        BLACK = ("black")
        RED = ("red")
        SIAMESE = ("siamese")
        BRITISH_SHORTHAIR = ("british_shorthair")
        CALICO = ("calico")
        PERSIAN = ("persian")
        RAGDOLL = ("ragdoll")
        WHITE = ("white")
        JELLIE = ("jellie")
        ALL_BLACK = ("all_black")


        def getKey(self) -> "NamespacedKey":
            ...



from .MapView import MapView
from .MapFont import MapFont
from .MapRenderer import MapRenderer
from .MinecraftFont import MinecraftFont
from .MapCanvas import MapCanvas
from .MapCursor import MapCursor
from .MapPalette import MapPalette
from .MapCursorCollection import MapCursorCollection


"""
Python module generated from Java source file com.google.common.collect.BaseImmutableMultimap

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class BaseImmutableMultimap(AbstractMultimap):
    """
    A dummy superclass of ImmutableMultimap that can be instanceof'd without ProGuard
    retaining additional implementation details of ImmutableMultimap.
    """





"""
Python module generated from Java source file org.bukkit.attribute.AttributeModifier

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from java.util import Objects
from java.util import UUID
from org.bukkit.attribute import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.util import NumberConversions
from typing import Any, Callable, Iterable, Tuple


class AttributeModifier(ConfigurationSerializable):
    """
    Concrete implementation of an attribute modifier.
    """

    def __init__(self, name: str, amount: float, operation: "Operation"):
        ...


    def __init__(self, uuid: "UUID", name: str, amount: float, operation: "Operation"):
        ...


    def __init__(self, uuid: "UUID", name: str, amount: float, operation: "Operation", slot: "EquipmentSlot"):
        ...


    def getUniqueId(self) -> "UUID":
        """
        Get the unique ID for this modifier.

        Returns
        - unique id
        """
        ...


    def getName(self) -> str:
        """
        Get the name of this modifier.

        Returns
        - name
        """
        ...


    def getAmount(self) -> float:
        """
        Get the amount by which this modifier will apply its Operation.

        Returns
        - modification amount
        """
        ...


    def getOperation(self) -> "Operation":
        """
        Get the operation this modifier will apply.

        Returns
        - operation
        """
        ...


    def getSlot(self) -> "EquipmentSlot":
        """
        Get the EquipmentSlot this AttributeModifier is active on,
        or null if this modifier is applicable for any slot.

        Returns
        - the slot
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    def equals(self, other: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def deserialize(args: dict[str, "Object"]) -> "AttributeModifier":
        ...


    class Operation(Enum):
        """
        Enumerable operation to be applied.
        """

        ADD_NUMBER = 0
        """
        Adds (or subtracts) the specified amount to the base value.
        """
        ADD_SCALAR = 1
        """
        Adds this scalar of amount to the base value.
        """
        MULTIPLY_SCALAR_1 = 2
        """
        Multiply amount by this value, after adding 1 to it.
        """



"""
Python module generated from Java source file com.google.common.collect.DenseImmutableTable

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.collect.ImmutableMap import IteratorBasedImmutableMap
from com.google.errorprone.annotations import Immutable
from com.google.j2objc.annotations import WeakOuter
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class DenseImmutableTable(RegularImmutableTable):
    """
    A `RegularImmutableTable` optimized for dense data.
    """

    def columnMap(self) -> "ImmutableMap"["C", dict["R", "V"]]:
        ...


    def rowMap(self) -> "ImmutableMap"["R", dict["C", "V"]]:
        ...


    def get(self, rowKey: "Object", columnKey: "Object") -> "V":
        ...


    def size(self) -> int:
        ...



from .VoxelShape import VoxelShape
from .EntityTransformer import EntityTransformer
from .EulerAngle import EulerAngle
from .StringUtil import StringUtil
from .BlockVector import BlockVector
from .FileUtil import FileUtil
from .Transformation import Transformation
from .BlockTransformer import BlockTransformer
from .ChatPaginator import ChatPaginator
from .CachedServerIcon import CachedServerIcon
from .BoundingBox import BoundingBox
from .BlockIterator import BlockIterator
from .Vector import Vector
from .Consumer import Consumer
from .StructureSearchResult import StructureSearchResult
from .NumberConversions import NumberConversions
from .RayTraceResult import RayTraceResult
from .BiomeSearchResult import BiomeSearchResult


from .UnknownDependencyException import UnknownDependencyException
from .ServicePriority import ServicePriority
from .SimpleServicesManager import SimpleServicesManager
from .Plugin import Plugin
from .RegisteredServiceProvider import RegisteredServiceProvider
from .PluginDescriptionResolver import PluginDescriptionResolver
from .InvalidPluginException import InvalidPluginException
from .IllegalPluginAccessException import IllegalPluginAccessException
from .PluginBase import PluginBase
from .PluginAwareness import PluginAwareness
from .SimplePluginManager import SimplePluginManager
from .PluginLoader import PluginLoader
from .PluginLogger import PluginLogger
from .RegisteredListener import RegisteredListener
from .PluginDescriptionFile import PluginDescriptionFile
from .InvalidDescriptionException import InvalidDescriptionException
from .ServicesManager import ServicesManager
from .EventExecutor import EventExecutor
from .TimedRegisteredListener import TimedRegisteredListener
from .PluginManager import PluginManager
from .AuthorNagException import AuthorNagException
from .PluginLoadOrder import PluginLoadOrder


"""
Python module generated from Java source file org.bukkit.block.Biome

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Biome(Enum):
    """
    Holds all accepted Biomes in the default server
    """

    OCEAN = 0
    PLAINS = 1
    DESERT = 2
    WINDSWEPT_HILLS = 3
    FOREST = 4
    TAIGA = 5
    SWAMP = 6
    MANGROVE_SWAMP = 7
    RIVER = 8
    NETHER_WASTES = 9
    THE_END = 10
    FROZEN_OCEAN = 11
    FROZEN_RIVER = 12
    SNOWY_PLAINS = 13
    MUSHROOM_FIELDS = 14
    BEACH = 15
    JUNGLE = 16
    SPARSE_JUNGLE = 17
    DEEP_OCEAN = 18
    STONY_SHORE = 19
    SNOWY_BEACH = 20
    BIRCH_FOREST = 21
    DARK_FOREST = 22
    SNOWY_TAIGA = 23
    OLD_GROWTH_PINE_TAIGA = 24
    WINDSWEPT_FOREST = 25
    SAVANNA = 26
    SAVANNA_PLATEAU = 27
    BADLANDS = 28
    WOODED_BADLANDS = 29
    SMALL_END_ISLANDS = 30
    END_MIDLANDS = 31
    END_HIGHLANDS = 32
    END_BARRENS = 33
    WARM_OCEAN = 34
    LUKEWARM_OCEAN = 35
    COLD_OCEAN = 36
    DEEP_LUKEWARM_OCEAN = 37
    DEEP_COLD_OCEAN = 38
    DEEP_FROZEN_OCEAN = 39
    THE_VOID = 40
    SUNFLOWER_PLAINS = 41
    WINDSWEPT_GRAVELLY_HILLS = 42
    FLOWER_FOREST = 43
    ICE_SPIKES = 44
    OLD_GROWTH_BIRCH_FOREST = 45
    OLD_GROWTH_SPRUCE_TAIGA = 46
    WINDSWEPT_SAVANNA = 47
    ERODED_BADLANDS = 48
    BAMBOO_JUNGLE = 49
    SOUL_SAND_VALLEY = 50
    CRIMSON_FOREST = 51
    WARPED_FOREST = 52
    BASALT_DELTAS = 53
    DRIPSTONE_CAVES = 54
    LUSH_CAVES = 55
    DEEP_DARK = 56
    MEADOW = 57
    GROVE = 58
    SNOWY_SLOPES = 59
    FROZEN_PEAKS = 60
    JAGGED_PEAKS = 61
    STONY_PEAKS = 62
    CHERRY_GROVE = 63
    CUSTOM = 64
    """
    Represents a custom Biome
    """


    def getKey(self) -> "NamespacedKey":
        ...



"""
Python module generated from Java source file com.google.gson.stream.JsonWriter

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.stream import *
from java.io import Closeable
from java.io import Flushable
from java.io import IOException
from java.io import Writer
from java.math import BigDecimal
from java.math import BigInteger
from java.util import Arrays
from java.util import Objects
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.atomic import AtomicLong
from java.util.regex import Pattern
from typing import Any, Callable, Iterable, Tuple


class JsonWriter(Closeable, Flushable):
    """
    Writes a JSON (<a href="http://www.ietf.org/rfc/rfc7159.txt">RFC 7159</a>)
    encoded value to a stream, one token at a time. The stream includes both
    literal values (strings, numbers, booleans and nulls) as well as the begin
    and end delimiters of objects and arrays.
    
    <h2>Encoding JSON</h2>
    To encode your data as JSON, create a new `JsonWriter`. Call methods
    on the writer as you walk the structure's contents, nesting arrays and objects
    as necessary:
    
      - To write <strong>arrays</strong>, first call .beginArray().
          Write each of the array's elements with the appropriate .value
          methods or by nesting other arrays and objects. Finally close the array
          using .endArray().
      - To write <strong>objects</strong>, first call .beginObject().
          Write each of the object's properties by alternating calls to
          .name with the property's value. Write property values with the
          appropriate .value method or by nesting other objects or arrays.
          Finally close the object using .endObject().
    
    
    <h2>Example</h2>
    Suppose we'd like to encode a stream of messages such as the following: ``` `[
      {
        "id": 912345678901,
        "text": "How do I stream JSON in Java?",
        "geo": null,
        "user": {
          "name": "json_newb",
          "followers_count": 41`
      },
      {
        "id": 912345678902,
        "text": "@json_newb just use JsonWriter!",
        "geo": [50.454722, -104.606667],
        "user": {
          "name": "jesse",
          "followers_count": 2
        }
      }
    ]}```
    This code encodes the above structure: ```   `public void writeJsonStream(OutputStream out, List<Message> messages) throws IOException {
        JsonWriter writer = new JsonWriter(new OutputStreamWriter(out, "UTF-8"));
        writer.setIndent("    ");
        writeMessagesArray(writer, messages);
        writer.close();`
    
      public void writeMessagesArray(JsonWriter writer, List<Message> messages) throws IOException {
        writer.beginArray();
        for (Message message : messages) {
          writeMessage(writer, message);
        }
        writer.endArray();
      }
    
      public void writeMessage(JsonWriter writer, Message message) throws IOException {
        writer.beginObject();
        writer.name("id").value(message.getId());
        writer.name("text").value(message.getText());
        if (message.getGeo() != null) {
          writer.name("geo");
          writeDoublesArray(writer, message.getGeo());
        } else {
          writer.name("geo").nullValue();
        }
        writer.name("user");
        writeUser(writer, message.getUser());
        writer.endObject();
      }
    
      public void writeUser(JsonWriter writer, User user) throws IOException {
        writer.beginObject();
        writer.name("name").value(user.getName());
        writer.name("followers_count").value(user.getFollowersCount());
        writer.endObject();
      }
    
      public void writeDoublesArray(JsonWriter writer, List<Double> doubles) throws IOException {
        writer.beginArray();
        for (Double value : doubles) {
          writer.value(value);
        }
        writer.endArray();
      }}```
    
    Each `JsonWriter` may be used to write a single JSON stream.
    Instances of this class are not thread safe. Calls that would result in a
    malformed JSON string will fail with an IllegalStateException.

    Author(s)
    - Jesse Wilson

    Since
    - 1.6
    """

    def __init__(self, out: "Writer"):
        """
        Creates a new instance that writes a JSON-encoded stream to `out`.
        For best performance, ensure Writer is buffered; wrapping in
        java.io.BufferedWriter BufferedWriter if necessary.
        """
        ...


    def setIndent(self, indent: str) -> None:
        """
        Sets the indentation string to be repeated for each level of indentation
        in the encoded document. If `indent.isEmpty()` the encoded document
        will be compact. Otherwise the encoded document will be more
        human-readable.

        Arguments
        - indent: a string containing only whitespace.
        """
        ...


    def setLenient(self, lenient: bool) -> None:
        """
        Configure this writer to relax its syntax rules. By default, this writer
        only emits well-formed JSON as specified by <a
        href="http://www.ietf.org/rfc/rfc7159.txt">RFC 7159</a>. Setting the writer
        to lenient permits the following:
        
          - Numbers may be Double.isNaN() NaNs or Double.isInfinite() infinities.
        """
        ...


    def isLenient(self) -> bool:
        """
        Returns True if this writer has relaxed syntax rules.
        """
        ...


    def setHtmlSafe(self, htmlSafe: bool) -> None:
        """
        Configure this writer to emit JSON that's safe for direct inclusion in HTML
        and XML documents. This escapes the HTML characters `<`, `>`,
        `&` and `=` before writing them to the stream. Without this
        setting, your XML/HTML encoder should replace these characters with the
        corresponding escape sequences.
        """
        ...


    def isHtmlSafe(self) -> bool:
        """
        Returns True if this writer writes JSON that's safe for inclusion in HTML
        and XML documents.
        """
        ...


    def setSerializeNulls(self, serializeNulls: bool) -> None:
        """
        Sets whether object members are serialized when their value is null.
        This has no impact on array elements. The default is True.
        """
        ...


    def getSerializeNulls(self) -> bool:
        """
        Returns True if object members are serialized when their value is null.
        This has no impact on array elements. The default is True.
        """
        ...


    def beginArray(self) -> "JsonWriter":
        """
        Begins encoding a new array. Each call to this method must be paired with
        a call to .endArray.

        Returns
        - this writer.
        """
        ...


    def endArray(self) -> "JsonWriter":
        """
        Ends encoding the current array.

        Returns
        - this writer.
        """
        ...


    def beginObject(self) -> "JsonWriter":
        """
        Begins encoding a new object. Each call to this method must be paired
        with a call to .endObject.

        Returns
        - this writer.
        """
        ...


    def endObject(self) -> "JsonWriter":
        """
        Ends encoding the current object.

        Returns
        - this writer.
        """
        ...


    def name(self, name: str) -> "JsonWriter":
        """
        Encodes the property name.

        Arguments
        - name: the name of the forthcoming value. May not be null.

        Returns
        - this writer.
        """
        ...


    def value(self, value: str) -> "JsonWriter":
        """
        Encodes `value`.

        Arguments
        - value: the literal string value, or null to encode a null literal.

        Returns
        - this writer.
        """
        ...


    def jsonValue(self, value: str) -> "JsonWriter":
        """
        Writes `value` directly to the writer without quoting or
        escaping. This might not be supported by all implementations, if
        not supported an `UnsupportedOperationException` is thrown.

        Arguments
        - value: the literal string value, or null to encode a null literal.

        Returns
        - this writer.

        Raises
        - UnsupportedOperationException: if this writer does not support
           writing raw JSON values.

        Since
        - 2.4
        """
        ...


    def nullValue(self) -> "JsonWriter":
        """
        Encodes `null`.

        Returns
        - this writer.
        """
        ...


    def value(self, value: bool) -> "JsonWriter":
        """
        Encodes `value`.

        Returns
        - this writer.
        """
        ...


    def value(self, value: "Boolean") -> "JsonWriter":
        """
        Encodes `value`.

        Returns
        - this writer.

        Since
        - 2.7
        """
        ...


    def value(self, value: float) -> "JsonWriter":
        """
        Encodes `value`.

        Arguments
        - value: a finite value, or if .setLenient(boolean) lenient,
            also Float.isNaN() NaN or Float.isInfinite()
            infinity.

        Returns
        - this writer.

        Raises
        - IllegalArgumentException: if the value is NaN or Infinity and this writer is not .setLenient(boolean) lenient.

        Since
        - 2.9.1
        """
        ...


    def value(self, value: float) -> "JsonWriter":
        """
        Encodes `value`.

        Arguments
        - value: a finite value, or if .setLenient(boolean) lenient,
            also Double.isNaN() NaN or Double.isInfinite() infinity.

        Returns
        - this writer.

        Raises
        - IllegalArgumentException: if the value is NaN or Infinity and this writer is
            not .setLenient(boolean) lenient.
        """
        ...


    def value(self, value: int) -> "JsonWriter":
        """
        Encodes `value`.

        Returns
        - this writer.
        """
        ...


    def value(self, value: "Number") -> "JsonWriter":
        """
        Encodes `value`. The value is written by directly writing the Number.toString()
        result to JSON. Implementations must make sure that the result represents a valid JSON number.

        Arguments
        - value: a finite value, or if .setLenient(boolean) lenient,
            also Double.isNaN() NaN or Double.isInfinite() infinity.

        Returns
        - this writer.

        Raises
        - IllegalArgumentException: if the value is NaN or Infinity and this writer is
            not .setLenient(boolean) lenient; or if the `toString()` result is not a
            valid JSON number.
        """
        ...


    def flush(self) -> None:
        """
        Ensures all buffered data is written to the underlying Writer
        and flushes that writer.
        """
        ...


    def close(self) -> None:
        """
        Flushes and closes this writer and the underlying Writer.

        Raises
        - IOException: if the JSON document is incomplete.
        """
        ...



from .Metadatable import Metadatable
from .MetadataEvaluationException import MetadataEvaluationException
from .FixedMetadataValue import FixedMetadataValue
from .MetadataStore import MetadataStore
from .MetadataConversionException import MetadataConversionException
from .LazyMetadataValue import LazyMetadataValue
from .MetadataValueAdapter import MetadataValueAdapter
from .MetadataValue import MetadataValue
from .MetadataStoreBase import MetadataStoreBase


from .MultipleCommandAlias import MultipleCommandAlias
from .ConsoleCommandSender import ConsoleCommandSender
from .CommandExecutor import CommandExecutor
from .PluginIdentifiableCommand import PluginIdentifiableCommand
from .Command import Command
from .CommandSender import CommandSender
from .TabExecutor import TabExecutor
from .CommandMap import CommandMap
from .CommandException import CommandException
from .TabCompleter import TabCompleter
from .PluginCommandYamlParser import PluginCommandYamlParser
from .BlockCommandSender import BlockCommandSender
from .RemoteConsoleCommandSender import RemoteConsoleCommandSender
from .FormattedCommandAlias import FormattedCommandAlias
from .PluginCommand import PluginCommand
from .ProxiedCommandSender import ProxiedCommandSender
from .SimpleCommandMap import SimpleCommandMap


"""
Python module generated from Java source file org.bukkit.event.player.PlayerItemDamageEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerItemDamageEvent(PlayerEvent, Cancellable):
    """
    Called when an item used by the player takes durability damage as a result of
    being used.
    """

    def __init__(self, player: "Player", what: "ItemStack", damage: int):
        ...


    def getItem(self) -> "ItemStack":
        """
        Gets the item being damaged.

        Returns
        - the item
        """
        ...


    def getDamage(self) -> int:
        """
        Gets the amount of durability damage this item will be taking.

        Returns
        - durability change
        """
        ...


    def setDamage(self, damage: int) -> None:
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.internal.LinkedTreeMap

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectStreamException
from java.io import Serializable
from java.util import AbstractSet
from java.util import Comparator
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class LinkedTreeMap(AbstractMap, Serializable):
    """
    A map of comparable keys to values. Unlike `TreeMap`, this class uses
    insertion order for iteration order. Comparison order is only used as an
    optimization for efficient insertion and removal.
    
    This implementation was derived from Android 4.1's TreeMap class.
    """

    def __init__(self):
        """
        Create a natural order, empty tree map whose keys must be mutually
        comparable and non-null, and whose values can be `null`.
        """
        ...


    def __init__(self, allowNullValues: bool):
        """
        Create a natural order, empty tree map whose keys must be mutually
        comparable and non-null.

        Arguments
        - allowNullValues: whether `null` is allowed as entry value
        """
        ...


    def __init__(self, comparator: "Comparator"["K"], allowNullValues: bool):
        """
        Create a tree map ordered by `comparator`. This map's keys may only
        be null if `comparator` permits.

        Arguments
        - comparator: the comparator to order elements with, or `null` to
            use the natural ordering.
        - allowNullValues: whether `null` is allowed as entry value
        """
        ...


    def size(self) -> int:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def clear(self) -> None:
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...


    def keySet(self) -> set["K"]:
        ...



from .PlayerSwapHandItemsEvent import PlayerSwapHandItemsEvent
from .PlayerItemHeldEvent import PlayerItemHeldEvent
from .PlayerItemMendEvent import PlayerItemMendEvent
from .PlayerEvent import PlayerEvent
from .PlayerToggleFlightEvent import PlayerToggleFlightEvent
from .PlayerPickupItemEvent import PlayerPickupItemEvent
from .PlayerChannelEvent import PlayerChannelEvent
from .PlayerCommandPreprocessEvent import PlayerCommandPreprocessEvent
from .PlayerRiptideEvent import PlayerRiptideEvent
from .PlayerPreLoginEvent import PlayerPreLoginEvent
from .PlayerInteractAtEntityEvent import PlayerInteractAtEntityEvent
from .PlayerToggleSneakEvent import PlayerToggleSneakEvent
from .PlayerRespawnEvent import PlayerRespawnEvent
from .PlayerInteractEvent import PlayerInteractEvent
from .PlayerBedEnterEvent import PlayerBedEnterEvent
from .PlayerBucketEntityEvent import PlayerBucketEntityEvent
from .AsyncPlayerChatEvent import AsyncPlayerChatEvent
from .PlayerUnleashEntityEvent import PlayerUnleashEntityEvent
from .PlayerPortalEvent import PlayerPortalEvent
from .PlayerEggThrowEvent import PlayerEggThrowEvent
from .PlayerLevelChangeEvent import PlayerLevelChangeEvent
from .PlayerRecipeDiscoverEvent import PlayerRecipeDiscoverEvent
from .PlayerExpCooldownChangeEvent import PlayerExpCooldownChangeEvent
from .PlayerRecipeBookClickEvent import PlayerRecipeBookClickEvent
from .PlayerBucketEvent import PlayerBucketEvent
from .PlayerAdvancementDoneEvent import PlayerAdvancementDoneEvent
from .PlayerChatTabCompleteEvent import PlayerChatTabCompleteEvent
from .PlayerShearEntityEvent import PlayerShearEntityEvent
from .PlayerDropItemEvent import PlayerDropItemEvent
from .PlayerHideEntityEvent import PlayerHideEntityEvent
from .PlayerChangedMainHandEvent import PlayerChangedMainHandEvent
from .PlayerFishEvent import PlayerFishEvent
from .PlayerChatEvent import PlayerChatEvent
from .PlayerQuitEvent import PlayerQuitEvent
from .PlayerLoginEvent import PlayerLoginEvent
from .PlayerChangedWorldEvent import PlayerChangedWorldEvent
from .PlayerVelocityEvent import PlayerVelocityEvent
from .PlayerHarvestBlockEvent import PlayerHarvestBlockEvent
from .PlayerShowEntityEvent import PlayerShowEntityEvent
from .PlayerEditBookEvent import PlayerEditBookEvent
from .PlayerCommandSendEvent import PlayerCommandSendEvent
from .PlayerBucketFillEvent import PlayerBucketFillEvent
from .AsyncPlayerChatPreviewEvent import AsyncPlayerChatPreviewEvent
from .PlayerRecipeBookSettingsChangeEvent import PlayerRecipeBookSettingsChangeEvent
from .PlayerExpChangeEvent import PlayerExpChangeEvent
from .PlayerBucketEmptyEvent import PlayerBucketEmptyEvent
from .PlayerToggleSprintEvent import PlayerToggleSprintEvent
from .PlayerRegisterChannelEvent import PlayerRegisterChannelEvent
from .PlayerItemConsumeEvent import PlayerItemConsumeEvent
from .AsyncPlayerPreLoginEvent import AsyncPlayerPreLoginEvent
from .PlayerSignOpenEvent import PlayerSignOpenEvent
from .PlayerMoveEvent import PlayerMoveEvent
from .PlayerStatisticIncrementEvent import PlayerStatisticIncrementEvent
from .PlayerItemDamageEvent import PlayerItemDamageEvent
from .PlayerResourcePackStatusEvent import PlayerResourcePackStatusEvent
from .PlayerSpawnChangeEvent import PlayerSpawnChangeEvent
from .PlayerAnimationEvent import PlayerAnimationEvent
from .PlayerKickEvent import PlayerKickEvent
from .PlayerTakeLecternBookEvent import PlayerTakeLecternBookEvent
from .PlayerBedLeaveEvent import PlayerBedLeaveEvent
from .PlayerAnimationType import PlayerAnimationType
from .PlayerUnregisterChannelEvent import PlayerUnregisterChannelEvent
from .PlayerLocaleChangeEvent import PlayerLocaleChangeEvent
from .PlayerTeleportEvent import PlayerTeleportEvent
from .PlayerArmorStandManipulateEvent import PlayerArmorStandManipulateEvent
from .PlayerItemBreakEvent import PlayerItemBreakEvent
from .PlayerPickupArrowEvent import PlayerPickupArrowEvent
from .PlayerGameModeChangeEvent import PlayerGameModeChangeEvent
from .PlayerJoinEvent import PlayerJoinEvent
from .PlayerBucketFishEvent import PlayerBucketFishEvent
from .PlayerInteractEntityEvent import PlayerInteractEntityEvent